<template>
    <div class="full-page bg">
        <div class="search-container">
            <el-form ref="form" :model="searchForm" label-width="auto">
                <el-row :gutter="20">
                    <el-col :span="6">
                        <el-form-item label="名称">
                            <el-input v-model="searchForm.demandTopic" clearable placeholder="请输入名称"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="6">
                        <el-form-item label="状态">
                            <el-select v-model="searchForm.value" placeholder="请选择">
                                <el-option v-for="item in options" :key="item.value" :label="item.name" :value="item.value">
                                </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="10">
                        <el-form-item label="时间">
                            <el-date-picker v-model="searchForm.value1" type="daterange" range-separator="至"
                                start-placeholder="开始日期" end-placeholder="结束日期">
                            </el-date-picker>
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch">
                            搜索
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="24" class="main-table-container flex">
            <el-col :span="4" class="table-tree">
                <el-input placeholder="输入关键字进行过滤" v-model="filterText">
                </el-input>
                <el-tree class="filter-tree" :data="data" :props="defaultProps" default-expand-all
                    :filter-node-method="filterNode" ref="tree">
                </el-tree>
            </el-col>
            <el-col :span="20" class="table-container" ref="contentPanel" style="padding: 20px">
                <div style="margin-bottom: 10px" ref="btnPanel">
                    <el-button icon="el-icon-plus" type="primary" class="btn btn-plus" @click="handleAdd">
                        添加
                    </el-button>
                    <el-button slot="reference" icon="el-icon-delete" type="danger" class="btn btn-delete"
                        :disabled="this.currentDataDel.length == 0" @click="handleDelete">
                        删除
                    </el-button>

                    <el-upload class="upload-demo" action="https://jsonplaceholder.typicode.com/posts/"
                        :on-success="handleSuccess" :on-remove="handleRemove">
                        <el-button type="success" icon="el-icon-folder-add">导入</el-button>
                    </el-upload>
                    <el-button type="warning" icon="el-icon-download">导出</el-button>
                </div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table stripe size="mini" v-loading="tableLoading" ref="multipleSelection" :data="tableData"
                        :max-height="tableMaxHeight" :style="{
                            width: '100%',
                            height: `${tableMaxHeight}` + 'px'
                        }" @selection-change="handleSelectionChange">
                        <el-table-column type="selection" width="55" align="center"></el-table-column>
                        <el-table-column type="index" width="55" label="序号" align="center">
                        </el-table-column>
                        <el-table-column prop="name" show-overflow-tooltip min-width="280" align="center" label="名称">
                        </el-table-column>
                        <el-table-column prop="state" show-overflow-tooltip width="290" align="center" label="状态">
                            <!-- <template v-slot="{ row }">
                                {{ getDictName('ggbb_lyqd', row.demandSourceChannel) }}
                            </template> -->
                        </el-table-column>
                        <el-table-column prop="time" show-overflow-tooltip min-width="280" align="center" label="时间">
                        </el-table-column>
                        <el-table-column show-overflow-tooltip min-width="180" align="center" fixed="right" label="操作">
                            <template v-slot="{ row }">
                                <el-link icon="el-icon-edit" type="primary" :underline="false" @click="handleDbClick(row)"
                                    style="margin-right: 10px;">
                                    编辑
                                </el-link>
                                <el-link icon="el-icon-delete" type="danger" :underline="false" @click="handleDelete(row)">
                                    删除
                                </el-link>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="params.pageBean"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
        <InformationRegDialog ref="InformationRegDialog"></InformationRegDialog>
        <!-- 弹层 -->

    </div>
</template>
  
<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import req from '@/request.js'
import utils from '@/utils.js'
import InformationRegDialog from './components/InformationRegDialog.vue'
const portal = window.context.portal
export default {
    name: 'DemandEntry',
    components: {
        pagination,
        InformationRegDialog
    },
    mixins: [TableMixin],
    data() {
        return {
            tableMaxHeight: 400,
            loading: false,
            tableLoading: false,
            tableData: [
                {
                    name: '张三',
                    state: '已认证',
                    time: '2023-10-30'
                },
                {
                    name: '李四',
                    state: '未认证',
                    time: '2023-10-29'
                }
            ],
            multipleSelection: [],
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0
                }
            },
            searchForm: {}, // 顶部搜索对象
            currentDataDel: [],
            options: [{
                name: '已认证', value: '1'
            }, {
                name: '未认证', value: '2'

            }],
            fileList: [{ name: 'food.jpeg', url: 'https://fuss10.elemecdn.com/3/63/4e7f3a15429bfda99bce42a18cdd1jpeg.jpeg?imageMogr2/thumbnail/360x360/format/webp/quality/100' }, { name: 'food2.jpeg', url: 'https://fuss10.elemecdn.com/3/63/4e7f3a15429bfda99bce42a18cdd1jpeg.jpeg?imageMogr2/thumbnail/360x360/format/webp/quality/100' }],
            filterText: '',
            data: [{
                id: 1,
                label: '一级 1',
                children: [{
                    id: 4,
                    label: '二级 1-1',
                    children: [{
                        id: 9,
                        label: '三级 1-1-1'
                    }, {
                        id: 10,
                        label: '三级 1-1-2'
                    }]
                }]
            }, {
                id: 2,
                label: '一级 2',
                children: [{
                    id: 5,
                    label: '二级 2-1'
                }, {
                    id: 6,
                    label: '二级 2-2'
                }]
            }, {
                id: 3,
                label: '一级 3',
                children: [{
                    id: 7,
                    label: '二级 3-1'
                }, {
                    id: 8,
                    label: '二级 3-2'
                }]
            }],
            defaultProps: {
                children: 'children',
                label: 'label'
            }
        }
    },

    created() {
    },
    watch: {
        filterText(val) {
            this.$refs.tree.filter(val);
        }
    },
    methods: {
        filterNode(value, data) {
            if (!value) return true;
            return data.label.indexOf(value) !== -1;
        },
        //字典回显
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        //获取数据
        loadData() {
            this.tableLoading = true
        },
        //添加
        handleAdd() {
            this.$refs.InformationRegDialog.add()
        },
        // 删除
        handleDelete() {
            this.$confirm('确定删除选中数据吗？', '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            }).then(() => {

            })
        },
        //修改
        handleDbClick(row) {
            this.$refs.InformationRegDialog.edit(row)
        },
        // 顶部搜索
        handleSearch() {

        },
        //表格选中
        handleSelectionChange(val) {
            this.currentDataDel = val
        },
        //分页页数
        handleCurrentChange(page) {
            this.params.pageBean = { ...this.params.pageBean, page }
            this.loadData(this.params)
        },
        //分页大小
        handleSizeChange(pageSize) {
            this.params.pageBean = { ...this.params.pageBean, pageSize }
            this.loadData(this.params)
        },
        //文件列表移除
        handleRemove(file, fileList) {
            console.log(file, fileList);
        },
        //文件上传成功
        handleSuccess(file) {
            console.log(file);
        },

    }
}
</script>
  
<style lang="scss" scoped>
.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.move-tree /deep/ .el-tree {
    height: 90%;
    overflow-y: auto;
    border: none;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(2) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //   background-color: #f56c6c;
    //   color: #fff;
    //   border-color: #f56c6c;
    // }
    /deep/ i,
    span {
        font-size: 16px;
    }
}

/deep/ .el-tree-node__content {
    padding: 5px 0;
}

/deep/.el-tree {
    border: none;

    .el-tree-node__label {
        font-size: 12px;
    }

    .el-tree-node__content {
        padding: 4px 0;
        box-sizing: border-box;
    }
}

/deep/.upload-demo {
    display: inline-block;
    margin: 0 10px;
}
</style>
  